#' Add a new report in a fairify project
#'
#' @param name Name of the report (sub-folder name in "reports")
#' @param path Path of the fairify project
#'
#' @return The path of the added report
#' @export
#'
#' @inherit create_reports examples
#'
add_report <- function(name, path = ".") {
  if (!dir.exists(file.path(path, "reports"))) {
    stop("Report structure not found, call `create_reports` first!")
  }
  destpath <- file.path(path, "reports", name)
  if (dir.exists(destpath))
    stop("The folder ",
         destpath,
         " exists already. Delete it first or choose another.")
  b <- file.copy(
    from = file.path(pkg_sys("bookdown_template")),
    to = file.path(path, "reports"),
    recursive = TRUE,
    copy.date = TRUE
  )
  if (any(!b))
    stop("The copy of the template report failed")
  file.rename(
    file.path(path, "reports", "bookdown_template"),
    destpath
  )
  return(destpath)
}
